/*
 * @(#)PopAttachmentsExample.java
 *
 * Copyright (c) JSCAPE LLC.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */

import com.jscape.inet.pop.*;
import com.jscape.inet.mime.*;
import com.jscape.inet.email.*;
import java.util.Enumeration;
import java.io.*;

public class PopAttachmentsExample {
    private static File messagesDir = new File("msg");
    private static File attachmentsDir = new File("attach");
    static BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
    
    // get messages from Pop mailbox
    public void getMessages(String hostname, String username, String password)
    throws PopException, MimeException, IOException {
        // ensure that messages directory is valid
        if(!messagesDir.exists()) {
            messagesDir.mkdir();
        }
        
        // ensure that attachments directory is valid
        if(!attachmentsDir.exists()) {
            attachmentsDir.mkdir();
        }
        
        // connect and login
        Pop pop = new Pop(hostname,username,password);
        pop.connect();        
		
		System.out.println("Retrieving messsages...");        
        
        // get message count
	int messageCount = pop.getMessageCount();
        if(messageCount < 1) {
            System.out.println("No messages found");
        } 
        
        // get messages and write messages to disk
	for(int i = 1; i <= messageCount; ++i) {
            EmailMessage msg = (EmailMessage)pop.getMessage(i);
            File f = new File(messagesDir,"msg" + i + ".txt");
            FileOutputStream fout = new FileOutputStream(f);
            fout.write(msg.getMessage());
            fout.close();
            System.out.println("Retrieved message: " + f.getAbsoluteFile());
            
            // write attachments to disk
            int attachnum = 0;
            Enumeration attachments = msg.getAttachments();
            while(attachments.hasMoreElements()) {
                ++attachnum;
                Attachment attach = (Attachment)attachments.nextElement();
                String attachmentFileName = attach.getFilename();
                if(attachmentFileName == null) {
                    attachmentFileName = "attachment" + i + "-" + attachnum;
                }
                
                String fileName = attach.getFilename();
                if(fileName == null) {
                	fileName = System.currentTimeMillis() + ".txt";
                }
                File attFile = new File(attachmentsDir,fileName);
                FileOutputStream attOut = new FileOutputStream(attFile);
                try {
                    attOut.write(attach.getFileData());
                    attOut.close();
                    System.out.println("Retrieved attachment: " + attFile.getAbsoluteFile());
                }
                catch(Exception e) {
                    throw new PopException("unable to decode file attachment");
                }
            }
        }
        pop.disconnect();
    }
    
    public static void main(String[] args) {
        String hostname;
        String username;
        String password;
        
        try {
            System.out.print("Enter Pop3 hostname (e.g. mail.domain.com): ");
            hostname = reader.readLine();
            System.out.print("Enter Pop3 Username: ");
            username = reader.readLine();
            System.out.print("Enter Pop3 Password: ");
            password = reader.readLine();
            PopAttachmentsExample example = new PopAttachmentsExample();
            example.getMessages(hostname,username,password);
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }
}

