/*
 * @(#)SFtpExample.java
 *
 * Copyright (c) JSCAPE LLC.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */
 
import com.jscape.inet.sftp.*;
import com.jscape.inet.sftp.events.*;
import com.jscape.inet.ssh.util.SshParameters;
import java.io.*;
import java.util.Enumeration;

public class SFtpExample extends SftpAdapter {
    private String sshHostname;
    private String sshUsername;
    private String sshPassword;
    
    /**
     * Creates a new SFtpExample instance.
     * @param sshHostname the SSH hostname
     * @param sshUsername the SSH username
     * @param sshPassword the SSH password
     */
    public SFtpExample(String sshHostname, String sshUsername, String sshPassword) {
        this.sshHostname = sshHostname;
        this.sshUsername = sshUsername;
        this.sshPassword = sshPassword;
    }    
    
    
    /**
     * Prints a directory listing from SSH server
     * @throws SftpException
     */
    public void getListing() throws SftpException {
    	
    	SshParameters params = new SshParameters(sshHostname,sshUsername,sshPassword);
    	
    	// create Sftp instance
        Sftp ftp = new Sftp(params);
        
        //capture SFTP related events
        ftp.addSftpListener(this);
        
        // establish SFTP connection
        ftp.connect();
        
        // get directory listing
        String results = ftp.getDirListingAsString();
        System.out.println(results);
        
        // disconnect
        ftp.disconnect();
    }
    
	/**
	 * Captures FtpConnectedEvent event
	 */
    public void connected(SftpConnectedEvent evt) {
        System.out.println("Connected to server: " + evt.getHostname());
    }
    
    /**
     * Captures FtpDisconnectedEvent event
     */
    public void disconnected(SftpDisconnectedEvent evt) {
        System.out.println("Disconnected from server: " + evt.getHostname());
    }
    
    
    public static void main(String[] args) {
        String sshHostname;
        String sshUsername;
        String sshPassword;
        try {
            BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
            System.out.print("Enter SSH hostname (e.g. ftp.myserver.com): ");
            sshHostname = reader.readLine();
            System.out.print("Enter SSH username (e.g. jsmith): ");
            sshUsername = reader.readLine();
            System.out.print("Enter SSH password (e.g. secret): ");
	    	sshPassword = reader.readLine();
	    	            
            SFtpExample example = new SFtpExample(sshHostname, sshUsername, sshPassword);
            	
	    
	    // print directory listing           	
            example.getListing();
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }
}

